%% Setpoints for the controllers

Md_s =  10; % [kg]1e2
TFG_eco_s = 4.247958315586494; %[K]1e2
Ta_s = 8.021500000000000; % [K]1e2
W_s = -10.631679771012628; %[W]1e6 
Tr_s = 7.516923357850542; % [K]1e2
Tc_s = 3.181500000000000; % [K]1e2


%% Controllers

% Md -- P Controller
theta1 = 0;
tauc1 = 1; 
k1 = 0.0216; 
Kcd = 1/(k1*(tauc1+theta1)); 

% TFG_eco -- I Controller
theta2 = 0;
tauc2 = 0.035;
k2 = 0.0491; 
I_TFG_eco = 1/(k2*(tauc2+theta2));


% Ta -- PI Controller
theta3 = 0;
tau3 = 0.0842;
k3 = -2.0987; 
tauc3 = 5.1111;
Kca_b = tau3/(k3*(tauc3+theta3)); 
tauITa = min(tau3,4*(tauc3+theta3)); 

% Tr -- I Controller
theta4 = 0; 
tauc4 = 0.025; 
k4 = 0.3161;
I_Tr = 1/(k4*(tauc4+theta4));

% Tc -- PI Controller
theta5 = 0; 
tau5 = 0.7060;
k5 = 3.8095e-07;
tauc5 = 4.5999;
KcTc = tau5/(k5*(tauc5+theta5));
tauITc = min(tau5,4*(tauc5+theta5));  

% W -- PI Controller
tau7 = 12.3216; 
theta7 = 0; 
k7 = -1.6141;
tauc7 = 4.111;
Kc_W = tau7/(k7*(tauc7+theta7)); 
tauIW = min(tau7,4*(tauc7+theta7));


K = [Kcd I_TFG_eco Kca_b I_Tr KcTc Kc_W]

%% Step in inputs

N_step = 0.01*N_nom*0; % [rad/s]
md_step = 0.01*md_nom*0; % [kg/s]
meco_b_step = 0.1*meco_b_nom*0; % [kg/s]
ma_b_step = 0.01*ma_b_nom*0; % [kg/s] 
mFG_r_step = 0.1*mFG_r_nom*0;
Qc_step = 0.01*Qc_nom*0; % [J/s] 

mFG_step = 0.01*mFG_nom*0; % [kg/s] 

N_step_time = 10; % [s]
meco_b_step_time = 10; % [s]
ma_b_step_time = 10; % [s]
mFG_r_step_time = 10; % [s)
Qc_step_time = 10; % [s]
mFG_step_time = 10; % [s]


CheckStepVector = [N_step meco_b_step ma_b_step mFG_r_step Qc_step mFG_step]

%% Step in setpoints

Md_s_step = 0.01*Md_s*0;
Md_s_step_time = 10;

TFG_eco_s_step = 0.01*TFG_eco_s*0;
TFG_eco_s_step_time = 10;

Ta_s_step = 0.01*Ta_s*0;
Ta_s_step_time = 10;

Tr_s_step = 0.01*Tr_s*0;
Tr_s_step_time = 10;

Tc_s_step = 0.01*Tc_s*0;
Tc_s_step_time = 10;

W_s_step = -0.01*W_s*0;
W_s_step_time = 10;

CheckSetpointStep = [Md_s_step TFG_eco_s_step Ta_s_step Tr_s_step Tc_s_step  W_s_step]