%% Setpoints for the controllers

Md_s =  10; % [kg]1e2
TFG_eco_s = 4.247958315586494; %[K]1e2
Ta_s = 8.021500000000000; % [K]1e2
zt_s = 0.900000; % [Pa]1e6
W_s = -10.63167977101263; %-10.631679771012628; %[W]1e6 
Tr_s = 7.516923357850542; % [K]1e2
Tc_s = 3.181500000000000; % [K]1e2


%% Controllers

% Md -- P Controller
theta1 = 0;
tauc1 = 1;
k1 = 0.0216; 
Kcd = 1/(k1*(tauc1+theta1)); 

% TFG_eco -- I Controller
theta2 = 0;
tauc2 = 0.035;
k2 = 0.0491; 
I_TFG_eco = 1/(k2*(tauc2+theta2));

% Ta -- PI Controller
theta3 = 0;
tau3 = 0.0925; 
k3 = -2.2025; 
tauc3 = 209.999;
Kca_b = tau3/(k3*(tauc3+theta3)); 
tauITa = min(tau3,4*(tauc3+theta3)); 

% Tr -- I Controller
theta4 = 0; 
tauc4 = 0.025; 
k4 = 0.3161;
I_Tr = 1/(k4*(tauc4+theta4));

% Tc -- PI Controller
theta5 = 0; 
tau5 =  0.6747; 
k5 = 3.8097809659911162631e-07;
tauc5 = 360.1111; 
KcTc = tau5/(k5*(tauc5+theta5));
tauITc = min(tau5,4*(tauc5+theta5)); 

% zt -- I Controller
kzt = -10.3222; 
tau1zt = 28.1051; 
tauczt = 49.99; 
thetazt = 0;
K_zt = tau1zt/(kzt*(tauczt+thetazt));
tauIzt = min(tau1zt,4*(tauczt+thetazt));
Kbzt = K_zt/tauIzt;

% W - PI Controller
theta7 = 0.1164;
k7 = -0.2528;
tau7 = 0.0129;
tauc7 = 19.999; 
Kc_W = tau7/(k7*(tauc7+theta7)); 
tauIW = min(tau7,4*(tauc7+theta7));
KbW = (Kc_W*0.01)/tauIW;

K = [Kcd I_TFG_eco Kca_b I_Tr KcTc K_zt Kc_W]


%% Step in inputs

N_step = 0.01*N_nom*0; % [rad/s]
meco_b_step = 0.01*meco_b_nom*0; % [kg/s]
ma_b_step = 0.01*ma_b_nom*0; % [kg/s] 
mFG_r_step = 0.1*mFG_r_nom*0;
Qc_step = -0.0001*Qc_nom*0; % [J/s] 

zt_step = 0.1*zt_nom*0; % [-]
mFG_step = 0.001*mFG_nom*0; % [kg/s] 


N_step_time = 10; % [s]
meco_b_step_time = 10; % [s]
ma_b_step_time = 10; % [s]
mFG_r_step_time = 10; % [s)
Qc_step_time = 100; % [s]
zt_step_time = 10; % [s]
mFG_step_time = 10; % [s]


CheckStepVector = [N_step meco_b_step ma_b_step mFG_r_step Qc_step mFG_step zt_step]

%% Step in setpoints

Md_s_step = 0.01*Md_s*0;
Md_s_step_time = 1;

TFG_eco_s_step = 0.01*TFG_eco_s*0;
TFG_eco_s_step_time = 1;

Ta_s_step = 0.0001*Ta_s*0;
Ta_s_step_time = 10;

Tr_s_step = 0.01*Tr_s*0;
Tr_s_step_time = 1;

Tc_s_step = 0.01*Tc_s*0;
Tc_s_step_time = 100;

zt_s_step = -0.1*zt_nom*0;
zt_s_step_time = 1;

W_s_step = -0.01*W_s*0;
W_s_step_time = 10;

CheckSetpointStep = [Md_s_step TFG_eco_s_step Ta_s_step Tr_s_step Tc_s_step zt_s_step W_s_step]