function dxBoilerdt = DAEBoiler(x,mmix,msh,TFGsh,mFG,Tmix,P)
% Dynamic states
Md = x(1)*1e2; Hd = x(2)*1e9; 
% Static states
Td = x(3)*1e2; TFGd = x(4)*1e2; 

% Parameters
CpFG = P(2); CpWater = P(3); Tref = P(5)*1e2; dHvap311 = P(7); UAd = P(16);


% Specific enthalpy [J/kg]
hmix = CpWater*(Tmix*1e2 - Tref); % In
hd = CpWater*(Td-Tref) + dHvap311; % Out

% Heat flow from heat exchanger [J/s]
Qd = UAd*((TFGd + TFGsh*1e3)/2 - (Td+Tmix*1e2)/2);

% Differential equations
dMddt = mmix - msh;  % Dynamic massbalance for the boiler
dHddt = Qd + mmix*hmix - msh*hd;  % Dynamic energybalance for the boiler

% Implicit algebraic equations
f1 = Hd - Md*hd; % To calculate Td
f2 = mFG*CpFG*(TFGsh*1e3-TFGd) - Qd; % To calculate TFGd


dxBoilerdt = [dMddt; dHddt*1e-6; f1*1e-2; f2*1e-3]; 
end
