%% Author: Ida Andersskog

clear
close all
clc;
warning off

%% Run parameters

runtime = 500;
relTol = 1e-8;

%% Floating pressure
run Init44.m
run CTFPSeq.m
W_s_step = -0.01*W_s; 
W_s_step_time = 50; 

sim('SteamCycleFP.slx')
PdFP = Pd;
WFP = W;
mFGFP = mFG;
ztFP = zt;
timeFP = time;

%% Boiler driven

run Init44.m
run CTBDSeq.m
W_s_step = -0.01*W_s; 
W_s_step_time = 50; 

sim('SteamCycleBD.slx')
PdBD = Pd;
WBD = W;
mFGBD = mFG;
ztBD = zt;
timeBD = time;

%% Turbine driven
run Init44.m
run CTTDSeq.m
relTol = 1e-7;
W_s_step = -0.01*W_s;
W_s_step_time = 50;

sim('SteamCycleTD.slx')
PdTD = Pd;
WTD = W;
mFGTD = mFG;
ztTD = zt;
timeTD = time;

%% Plotting

set(0,'DefaultTextFontName','Times',...
'DefaultTextFontSize',30,...
'DefaultAxesFontName','Times',...
'DefaultAxesFontSize',31,...
'DefaultLineLineWidth',2.5,...
'DefaultLineMarkerSize',7.75,...
'DefaultStairLineWidth',1);
set(findall(gcf,'Type','text'),'FontSize',30,'Interpreter','latex');
set(gcf,'color','white');

fullfig(1)

n = 2;
m = 2;

subplot(n,m,1)
plot(timeBD,WBD,timeTD,WTD,timeFP,WFP,timeTD,W_s)
xlabel('Time [s]')
ylabel('Power [MW]')
legend('W_{BD}','W_{TD}','W_{FP}','W_{s}')

subplot(n,m,2)
plot(timeBD,PdBD,timeTD,PdTD,timeFP,PdFP,timeTD,Pd_s)
xlabel('Time [s]')
ylabel('Pressure [MPa]')
legend('P_{d,BD}','P_{d,TD}','P_{d,FP}','P_{ds}')

subplot(n,m,4)
plot(timeBD,mFGBD,timeTD,mFGTD,timeFP,mFGFP)
xlabel('Time [s]')
ylabel('Flue gas [kg/s]')
legend('m_{FG,BD}','m_{FG,TD}','m_{FG,FP}')

subplot(n,m,3)
plot(timeBD,ztBD,timeTD,ztTD,timeFP,ztFP)
xlabel('Time [s]')
ylabel('Valve position')
legend('z_{t,BD}','z_{t,TD}','z_{t,FP}')


