%% Author: Ida Andersskog

clear
close all
clc;
warning off

%% Run parameters

runtime = 5000;
relTol = 1e-8;


%% VPC
run Init44.m
run CTTDVPC.m
W_s_step = 0.01*W_s;
W_s_step_time = 100;

sim('SteamCycleTDVPC.slx')

PdVPC = Pd;
WVPC = W;
mFGVPC = mFG;
ztVPC = zt;
timeVPC = time;

%% Turbine driven
run Init44.m
run CTTDSeq.m
relTol = 1e-7;
W_s_step = 0.01*W_s;
W_s_step_time = 100;

sim('SteamCycleTD.slx')
PdTD = Pd;
WTD = W;
mFGTD = mFG;
ztTD = zt;
timeTD = time;

%%

set(0,'DefaultTextFontName','Times',...
'DefaultTextFontSize',30,...
'DefaultAxesFontName','Times',...
'DefaultAxesFontSize',30,...
'DefaultLineLineWidth',2.5,...
'DefaultLineMarkerSize',7.75,...
'DefaultStairLineWidth',1);
set(findall(gcf,'Type','text'),'FontSize',30,'Interpreter','latex');
set(gcf,'color','white');

fullfig(1)

n = 2;
m = 2;

subplot(n,m,1)
plot(timeTD,WTD,timeVPC,WVPC,timeTD,W_s)
xlabel('Time [s]')
ylabel('Power [MW]')
legend('W_{TD}','W_{VPC}','W_{s}')

subplot(n,m,2)
plot(timeTD,PdTD,timeVPC,PdVPC,timeTD,Pd_s)
xlabel('Time [s]')
ylabel('Pressure [MPa]')
legend('P_{d,TD}','P_{d,VPC}','P_{ds}')

subplot(n,m,4)
plot(timeTD,mFGTD,timeVPC,mFGVPC)
xlabel('Time [s]')
ylabel('Flue gas [kg/s]')
legend('m_{FG,TD}','m_{FG,VPC}')

subplot(n,m,3)
plot(timeTD,ztTD, timeVPC, ztVPC, timeVPC, zt_s)
xlabel('Time [s]')
ylabel('Valve position')
legend('z_{t,TD}','z_{t,VPC}','z_{ts}')
