
%% Nominal values
N_nom = 211.92; % [rad/s]
md_nom = 5.9750; % [kg/s] inlet flow of boiler/Evaporator
meco_b_nom = 0.5; % [kg/s] bypass flow Economizer
msh_nom = md_nom; % [kg/s] outlet flow of boiler
ma_b_nom = 0.310784629432208; %0.311;% bypass stream [kg/s]
zt_nom =  0.9;  %  Valve opening 
mFG_nom = 20; % flue gas in HEX [kg/s] 
mFG_r_nom = 5; % flue gas in reheater [kg/s]

%% Fixed initial conditions

% Holdups
Md_0 = 10; % [kg]1e2 Boiler drum holdup
Ma_0 = 2.645; % [kg]10 Attemperator holdup
Mt_0 = 2.508; % [kg]1e-1 Turbine
Mc_0 = 5; % [kg] 10 Condenser holdup
Meco_0 = 1; % [kh] Economizer holdup

% Temperatures
Tref = 3.1815; % [K]1e2 Reference temperauture
Tc_0 = Tref;
Td_0 = 5.840688; % [K]1e2
Tsh_0 = 8.7678;  % [K]1e2
Tr_0 = 7.516923357850542; %6.074421806784751; %6.139593;  % [K]1e2
Teco_0 = Td_0;  % [K]1e2

% Flows
meco_0 = md_nom - meco_b_nom; % [kg/s]
mmix_0 = meco_0 + meco_b_nom; % |kg/s]

%% Parameters

CpSteam = 2e3; % Heat capacity steam (gas)  [J/kg,K] 
CpFG = 1063.1; % Heat capacity methane [J/kg,K]
CpWater = 4.18e3; % Heat capacity liquid water [J/kg,K]

dHvap311 = 1321.9e3; % Heat of vap at 311C [J/kg]
dHvap45 = 2394e3; % Heat of vap at 45C [J/kg]
TFG0 = 1000 + 273.15; % Initial temperature gas [K]
Trefbp = Td_0; % Treference temperature gas boiling point [K]1e2

Antoine.A = 5.11564; % Antoine parameters
Antoine.B = 1687.537;
Antoine.C = -42.98;

Mmwater = 18e-3; % Mole weight water [kg/mol]
R = 8.3145; % Gas constant [J/mol,K]
V = 1; % Volume in mixer and turbine holdup


%% Heat exchangers 

run SS_Hex.m
UAsh = double(sol.UAsh);  % [W/m2K]
UAd = double(sol.UAd);  % [W/m2K]
UAeco = double(sol.UAeco);  % [W/m2K]
UAr = double(sol.UAr); % [W/m2K]
Tmix_0 = double(sol.Tmix)*1e-2;  % [K]1e2
TFG_sh_0 =  double(sol.TFGsh)*1e-3;   % [K]1e3
TFG_d_0 =  double(sol.TFGd)*1e-2;   % [K]1e2
TFG_eco_0 =  double(sol.TFGeco)*1e-2;   % [K]1e2
TFG_r_0 = double(sol.TFGr)*1e-2; % [K]1e2
Hd_0 = Hd*1e-9; % [J]1e9

%% Parameter vector

P = [CpSteam CpFG CpWater Mmwater Tref Trefbp dHvap311 dHvap45 Antoine.A ...
    Antoine.B Antoine.C R V TFG0 UAsh UAd UAeco UAr];

Np = size(P,2);

%% Initial guess

Ta_0 = ((((md_nom*(CpWater*(Td_0-Tref)*1e2 + dHvap311 + ...
    CpSteam*(Tsh_0-Td_0)*1e2)/(md_nom+ma_b_nom))-(CpWater*(Td_0-Tref)*1e2...
    + dHvap311))/CpSteam)...
    + Td_0*1e2)*1e-2; % [K] 1e2

% Pressures 
Pa_0 = rhoEqPa([Ma_0; Ta_0],P); % [Pa]1e6
Pt_in_0 = rhoEqPt(Mt_0, Ta_0,P);  % [Pa]1e6
Pt_out_0 = AntoineEq2(Tc_0,P);  % [Pa]1e3
Pt_hp_0 = (Pt_in_0*1e6*(390/(Ta_0*1e2))^(1/0.23))*1e-5; % [Pa]1e5

% Valve coefficient for msh 
Kmsh = md_nom/(AntoineEq(Td_0,P)*1e6 - Pa_0*1e6); 
% Valve coefficient for ma
Kma = (md_nom+ma_b_nom)/(zt_nom*(Pa_0*1e6-Pt_in_0*1e6)); 
% Stodola coefficient
Kt = (md_nom+ma_b_nom)/sqrt((Pt_in_0*1e6*Mmwater/...
    (R*Ta_0*1e2))*Pt_in_0*1e6*(1-((Pt_out_0*1e3)/(Pt_in_0*1e6))^2)); 

% Constant volumetric flow coefficient
q3s = (md_nom+ma_b_nom)/((Pt_in_0*1e6*Mmwater)/(R*Ta_0*1e2)); 
%%
run SS_Turbine_Condenser.m
Qc_nom = Qc_r; % [J/s] 

%%
Mdyn = [1 0 0; 0 1 0];  
Malg = [0 0 1];
