% Clearing
clear
close all
clc;

% Locating variables
syms k1 k3 dPs dPq

% Parameters
rho_ref = 974; % Average fluid denisty kg/m^3
N = 211.92; % rad/s Pump speed demand
P_in = 9.614638196694839*1e3; % Pa Inlet pressure
rho = 970; % kg/m^3 Inlet density
m = 6.285784629432207; % Mass flow kg/s
F = m/rho; % Volumetric flow m^3/s
P_out = 100e5; % Outlet pressure [Pa]
dP = P_out - P_in;
k2 = 0;

f(1) = F - N*(k1/(k2+(1/k3)))^(0.5); % Volumetric flow 
f(2) = dPq - k3*rho_ref*F^2; % Pressure drop across load
f(3) = dP - (dPs + dPq); % Pressure rise across pump
f(4) = dPs/dP - 0.6766; % Static to total pressure difference ratio

sol = solve(f,k1,k3,dPq,dPs);
k1  = double(sol.k1)  % [m^2]
k3  = double(sol.k3)  % [m^-4]
dPq = double(sol.dPq) % [Pa], static pressure rise across the pump
dPs = double(sol.dPs) % [Pa], Pressure drop across load
 